#line 2 "src/pParse_flex.c"

#line 4 "src/pParse_flex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer pParse_flex_create_buffer
#define yy_delete_buffer pParse_flex_delete_buffer
#define yy_flex_debug pParse_flex_flex_debug
#define yy_init_buffer pParse_flex_init_buffer
#define yy_flush_buffer pParse_flex_flush_buffer
#define yy_load_buffer_state pParse_flex_load_buffer_state
#define yy_switch_to_buffer pParse_flex_switch_to_buffer
#define yyin pParse_flexin
#define yyleng pParse_flexleng
#define yylex pParse_flexlex
#define yylineno pParse_flexlineno
#define yyout pParse_flexout
#define yyrestart pParse_flexrestart
#define yytext pParse_flextext
#define yywrap pParse_flexwrap
#define yyalloc pParse_flexalloc
#define yyrealloc pParse_flexrealloc
#define yyfree pParse_flexfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE pParse_flexrestart(pParse_flexin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int pParse_flexleng;

extern FILE *pParse_flexin, *pParse_flexout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE pParse_flexlex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-pParse_flexlineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < pParse_flexleng; ++yyl )\
                    if ( pParse_flextext[yyl] == '\n' )\
                        --pParse_flexlineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pParse_flextext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up pParse_flextext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via pParse_flexrestart()), so that the user can continue scanning by
	 * just pointing pParse_flexin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when pParse_flextext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int pParse_flexleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow pParse_flexwrap()'s to do buffer switches
 * instead of setting up a fresh pParse_flexin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void pParse_flexrestart (FILE *input_file  );
void pParse_flex_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE pParse_flex_create_buffer (FILE *file,int size  );
void pParse_flex_delete_buffer (YY_BUFFER_STATE b  );
void pParse_flex_flush_buffer (YY_BUFFER_STATE b  );
void pParse_flexpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void pParse_flexpop_buffer_state (void );

static void pParse_flexensure_buffer_stack (void );
static void pParse_flex_load_buffer_state (void );
static void pParse_flex_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER pParse_flex_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE pParse_flex_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE pParse_flex_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE pParse_flex_scan_bytes (yyconst char *bytes,int len  );

void *pParse_flexalloc (yy_size_t  );
void *pParse_flexrealloc (void *,yy_size_t  );
void pParse_flexfree (void *  );

#define yy_new_buffer pParse_flex_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        pParse_flexensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pParse_flex_create_buffer(pParse_flexin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        pParse_flexensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pParse_flex_create_buffer(pParse_flexin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *pParse_flexin = (FILE *) 0, *pParse_flexout = (FILE *) 0;

typedef int yy_state_type;

extern int pParse_flexlineno;

int pParse_flexlineno = 1;

extern char *pParse_flextext;
#define yytext_ptr pParse_flextext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up pParse_flextext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	pParse_flexleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 20
#define YY_END_OF_BUFFER 21
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[135] =
    {   0,
        0,    0,   21,   19,   18,   18,   17,   19,   10,   16,
       15,   15,   13,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   10,   10,   10,    0,   15,   15,   14,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
        0,   10,    0,   10,    1,   15,   11,   15,   15,   15,
       15,   15,   12,   15,    0,   10,    0,   15,   15,   15,
       15,   15,   15,   15,    0,   10,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,   15,   15,   15,    7,   15,    8,   15,   15,   15,

        5,   15,   15,   15,    6,   15,   15,   15,   15,   15,
       15,   15,   15,   15,   15,   15,   15,    4,   15,   15,
       15,   15,   15,   15,    3,   15,   15,   15,   15,   15,
       15,    9,    2,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    5,    6,    5,    6,    7,    5,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    1,    9,    1,
        5,    1,    1,    1,   10,   10,   10,   11,   12,   10,
       10,   10,   13,   10,   10,   10,   10,   14,   10,   15,
       10,   10,   16,   10,   10,   10,   10,   10,   10,   10,
       17,    1,   17,    5,   18,    1,   19,   20,   21,   22,

       23,   24,   25,   26,   27,   10,   10,   28,   29,   30,
       31,   32,   10,   33,   34,   35,   36,   37,   38,   39,
       10,   10,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[40] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    1,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2
    } ;

static yyconst flex_int16_t yy_base[136] =
    {   0,
        0,    0,  170,  171,  171,  171,  171,  161,   33,  171,
        0,  154,    0,  140,  135,  142,  125,  127,  131,   23,
      134,  141,  140,   35,   36,   43,   54,    0,  147,    0,
       19,  133,  124,  125,  125,   28,  115,  122,  121,  117,
       59,   56,  141,  140,    0,  113,    0,  119,  124,  126,
      124,  116,    0,  114,  132,  131,   63,  103,  107,  101,
       98,  105,   96,  113,  123,  122,  110,  105,  100,  107,
      102,  105,  103,   92,   99,   89,   86,   83,   84,   88,
       80,   98,   83,   85,   88,   83,   86,  104,   71,  102,
       86,   71,   84,   66,  171,   82,  171,   81,   96,   79,

      171,   73,   73,   68,  171,   67,   61,   57,   69,   68,
       59,   59,   70,   83,   50,   64,   58,  171,   50,   46,
       47,   74,   50,   45,  171,   44,   38,   43,   40,   53,
       48,  171,  171,  171,   44
    } ;

static yyconst flex_int16_t yy_def[136] =
    {   0,
      134,    1,  134,  134,  134,  134,  134,  134,  134,  134,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  134,  134,  134,  134,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      134,  134,  134,  134,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  134,  134,  134,  135,  135,  135,
      135,  135,  135,  135,  134,  134,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  134,  135,  134,  135,  135,  135,

      134,  135,  135,  135,  134,  135,  135,  135,  135,  135,
      135,  135,  135,  135,  135,  135,  135,  134,  135,  135,
      135,  135,  135,  135,  134,  135,  135,  135,  135,  135,
      135,  134,  134,    0,  134
    } ;

static yyconst flex_int16_t yy_nxt[211] =
    {   0,
        4,    5,    6,    5,    7,    7,    8,    9,   10,   11,
       11,   12,   13,   11,   14,   11,    4,    4,   11,   11,
       15,   16,   17,   18,   11,   19,   11,   11,   11,   11,
       11,   20,   11,   21,   22,   11,   23,   11,   11,   25,
       26,   36,   24,   42,   27,   28,   41,   27,   46,   25,
       26,  133,   47,   37,   27,   27,  132,   41,   27,   43,
       51,   44,   52,   42,   55,   27,   56,   57,   65,  101,
       66,  131,  130,  129,  128,  127,  126,  125,   57,  124,
      123,  122,  121,  102,  120,  119,  118,  117,  116,  115,
      114,  113,  112,  111,  110,  109,  108,  107,  106,  105,

      104,  103,  100,   99,   98,   97,   96,   95,   94,   93,
       92,   91,   90,   89,   88,   87,   86,   85,   84,   83,
       82,   81,   80,   79,   78,   77,   76,   75,   74,   66,
       66,   73,   72,   71,   70,   69,   68,   67,   56,   56,
       64,   63,   62,   61,   60,   59,   58,   44,   44,   54,
       47,   47,   53,   50,   49,   47,   48,   45,   40,   39,
       38,   35,   34,   33,   32,   31,   30,   29,   24,  134,
        3,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,

      134,  134,  134,  134,  134,  134,  134,  134,  134,  134
    } ;

static yyconst flex_int16_t yy_chk[211] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    9,
        9,   20,   24,   25,    9,  135,   24,   25,   31,   26,
       26,  131,   31,   20,   26,    9,  130,   24,   25,   27,
       36,   27,   36,   42,   41,   26,   41,   42,   57,   94,
       57,  129,  128,  127,  126,  124,  123,  122,   42,  121,
      120,  119,  117,   94,  116,  115,  114,  113,  112,  111,
      110,  109,  108,  107,  106,  104,  103,  102,  100,   99,

       98,   96,   93,   92,   91,   90,   89,   88,   87,   86,
       85,   84,   83,   82,   81,   80,   79,   78,   77,   76,
       75,   74,   73,   72,   71,   70,   69,   68,   67,   66,
       65,   64,   63,   62,   61,   60,   59,   58,   56,   55,
       54,   52,   51,   50,   49,   48,   46,   44,   43,   40,
       39,   38,   37,   35,   34,   33,   32,   29,   23,   22,
       21,   19,   18,   17,   16,   15,   14,   12,    8,    3,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,

      134,  134,  134,  134,  134,  134,  134,  134,  134,  134
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[21] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
    0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int pParse_flex_flex_debug;
int pParse_flex_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *pParse_flextext;
#line 1 "pParse_flex.l"
#line 2 "pParse_flex.l"
// Copyright (C) 2013 Daniel J. Bates, Jonathan D. Hauenstein, Andrew J. Sommese, and Charles W. Wampler

#include "ppParse.h"
#include "pParse_bison.h"

#define pParse_flexlex pParse_bisonlex


variablegroupArray *pVarGpArray = NULL;
definedSubfuncStack *pActiveSFData = NULL;
parseArray *pArray = NULL;

// processing line
char *pLine = NULL;
int pLineLen = 0, pCurrNumber = 0, pAddAllNums = 0;

extern int *pendOfFile;
extern int *plineNum;

/* %option nounput - do not warn about unput */
#line 598 "src/pParse_flex.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int pParse_flexlex_destroy (void );

int pParse_flexget_debug (void );

void pParse_flexset_debug (int debug_flag  );

YY_EXTRA_TYPE pParse_flexget_extra (void );

void pParse_flexset_extra (YY_EXTRA_TYPE user_defined  );

FILE *pParse_flexget_in (void );

void pParse_flexset_in  (FILE * in_str  );

FILE *pParse_flexget_out (void );

void pParse_flexset_out  (FILE * out_str  );

int pParse_flexget_leng (void );

char *pParse_flexget_text (void );

int pParse_flexget_lineno (void );

void pParse_flexset_lineno (int line_number  );

YYSTYPE * pParse_flexget_lval (void );

void pParse_flexset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int pParse_flexwrap (void );
#else
extern int pParse_flexwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( pParse_flextext, pParse_flexleng, 1, pParse_flexout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		unsigned n; \
		for ( n = 0; n < max_size && \
			     (c = getc( pParse_flexin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( pParse_flexin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, pParse_flexin))==0 && ferror(pParse_flexin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(pParse_flexin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int pParse_flexlex \
               (YYSTYPE * yylval_param );

#define YY_DECL int pParse_flexlex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after pParse_flextext and pParse_flexleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 50 "pParse_flex.l"


#line 789 "src/pParse_flex.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! pParse_flexin )
			pParse_flexin = stdin;

		if ( ! pParse_flexout )
			pParse_flexout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			pParse_flexensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				pParse_flex_create_buffer(pParse_flexin,YY_BUF_SIZE );
		}

		pParse_flex_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of pParse_flextext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 135 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 171 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < pParse_flexleng; ++yyl )
				if ( pParse_flextext[yyl] == '\n' )
					   
    pParse_flexlineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 52 "pParse_flex.l"
{ // end of file
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pEND;
           }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 56 "pParse_flex.l"
{ // hom variable group
             append_str(&pLine, &pLineLen, pParse_flextext);
             return pHOMVARGP;
           }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 60 "pParse_flex.l"
{ // variable group
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pVARGP;
           }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 64 "pParse_flex.l"
{ // path variable
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pPATHVAR;
           }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 68 "pParse_flex.l"
{ // variable
             append_str(&pLine, &pLineLen, pParse_flextext);
      	     return pVAR;
           }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 72 "pParse_flex.l"
{ // parameter
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pPARAM;
           }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 76 "pParse_flex.l"
{ // const
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pCONST;
           }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 80 "pParse_flex.l"
{ // function
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pFUNC;
           }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 84 "pParse_flex.l"
{ // defined subfunction
             append_str(&pLine, &pLineLen, pParse_flextext);
             return pSUBFUNC;
           } 
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 88 "pParse_flex.l"
{ // number
             append_str(&pLine, &pLineLen, pParse_flextext);
	     pParse_bisonlval.name = strdup(pParse_flextext);
	     return pNUMBER;
           }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 93 "pParse_flex.l"
{ // sin, cos, tan, or exp
             append_str(&pLine, &pLineLen, pParse_flextext);
	     pParse_bisonlval.name = strdup(pParse_flextext);
	     return pSCE;
	   }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 98 "pParse_flex.l"
{ // pow 
             append_str(&pLine, &pLineLen, pParse_flextext);
             pParse_bisonlval.name = strdup(pParse_flextext);
             return pPOW;
           }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 103 "pParse_flex.l"
{ // I
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pI;
           }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 107 "pParse_flex.l"
{ // Pi
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pPi;
           }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 111 "pParse_flex.l"
{ // name
             append_str(&pLine, &pLineLen, pParse_flextext);
             pParse_bisonlval.name = strdup(pParse_flextext);
	     return pNAME;
           }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 116 "pParse_flex.l"
{ // end of line
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pEOL;
           }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 120 "pParse_flex.l"
{ // -+*/^(),=
             append_str(&pLine, &pLineLen, pParse_flextext);
	     return pParse_flextext[0];
           }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 124 "pParse_flex.l"
; // ignore it
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 125 "pParse_flex.l"
{ // other symbol - error!
             append_str(&pLine, &pLineLen, pParse_flextext);
	     pParse_bisonerror("invalid character");
           }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 130 "pParse_flex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1043 "src/pParse_flex.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed pParse_flexin at a new source and called
			 * pParse_flexlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = pParse_flexin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( pParse_flexwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * pParse_flextext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of pParse_flexlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					pParse_flexrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			pParse_flexrestart(pParse_flexin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) pParse_flexrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 135 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 135 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 134);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					pParse_flexrestart(pParse_flexin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( pParse_flexwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve pParse_flextext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    pParse_flexlineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void pParse_flexrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        pParse_flexensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            pParse_flex_create_buffer(pParse_flexin,YY_BUF_SIZE );
	}

	pParse_flex_init_buffer(YY_CURRENT_BUFFER,input_file );
	pParse_flex_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void pParse_flex_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		pParse_flexpop_buffer_state();
	 *		pParse_flexpush_buffer_state(new_buffer);
     */
	pParse_flexensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	pParse_flex_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (pParse_flexwrap()) processing, but the only time this flag
	 * is looked at is after pParse_flexwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void pParse_flex_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	pParse_flexin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE pParse_flex_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) pParse_flexalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pParse_flex_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) pParse_flexalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in pParse_flex_create_buffer()" );

	b->yy_is_our_buffer = 1;

	pParse_flex_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with pParse_flex_create_buffer()
 * 
 */
    void pParse_flex_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		pParse_flexfree((void *) b->yy_ch_buf  );

	pParse_flexfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a pParse_flexrestart() or at EOF.
 */
    static void pParse_flex_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	pParse_flex_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then pParse_flex_init_buffer was _probably_
     * called from pParse_flexrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void pParse_flex_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		pParse_flex_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void pParse_flexpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	pParse_flexensure_buffer_stack();

	/* This block is copied from pParse_flex_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from pParse_flex_switch_to_buffer. */
	pParse_flex_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void pParse_flexpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	pParse_flex_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		pParse_flex_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void pParse_flexensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)pParse_flexalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pParse_flexensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)pParse_flexrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in pParse_flexensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE pParse_flex_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) pParse_flexalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pParse_flex_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	pParse_flex_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to pParse_flexlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       pParse_flex_scan_bytes() instead.
 */
YY_BUFFER_STATE pParse_flex_scan_string (yyconst char * yystr )
{
    
	return pParse_flex_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to pParse_flexlex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE pParse_flex_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) pParse_flexalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in pParse_flex_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = pParse_flex_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in pParse_flex_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pParse_flextext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		pParse_flextext[pParse_flexleng] = (yy_hold_char); \
		(yy_c_buf_p) = pParse_flextext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		pParse_flexleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int pParse_flexget_lineno  (void)
{
        
    return pParse_flexlineno;
}

/** Get the input stream.
 * 
 */
FILE *pParse_flexget_in  (void)
{
        return pParse_flexin;
}

/** Get the output stream.
 * 
 */
FILE *pParse_flexget_out  (void)
{
        return pParse_flexout;
}

/** Get the length of the current token.
 * 
 */
int pParse_flexget_leng  (void)
{
        return pParse_flexleng;
}

/** Get the current token.
 * 
 */

char *pParse_flexget_text  (void)
{
        return pParse_flextext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void pParse_flexset_lineno (int  line_number )
{
    
    pParse_flexlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see pParse_flex_switch_to_buffer
 */
void pParse_flexset_in (FILE *  in_str )
{
        pParse_flexin = in_str ;
}

void pParse_flexset_out (FILE *  out_str )
{
        pParse_flexout = out_str ;
}

int pParse_flexget_debug  (void)
{
        return pParse_flex_flex_debug;
}

void pParse_flexset_debug (int  bdebug )
{
        pParse_flex_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from pParse_flexlex_destroy(), so don't allocate here.
     */

    /* We do not touch pParse_flexlineno unless the option is enabled. */
    pParse_flexlineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    pParse_flexin = stdin;
    pParse_flexout = stdout;
#else
    pParse_flexin = (FILE *) 0;
    pParse_flexout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * pParse_flexlex_init()
     */
    return 0;
}

/* pParse_flexlex_destroy is for both reentrant and non-reentrant scanners. */
int pParse_flexlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		pParse_flex_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		pParse_flexpop_buffer_state();
	}

	/* Destroy the stack itself. */
	pParse_flexfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * pParse_flexlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *pParse_flexalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *pParse_flexrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void pParse_flexfree (void * ptr )
{
	free( (char *) ptr );	/* see pParse_flexrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 130 "pParse_flex.l"



void clear_definedSubfuncData(definedSubfuncData *subFunc)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear subFunc                                          *
\***************************************************************/
{
  if (subFunc->numArguments > 0)
  { // clear arguments
    free(subFunc->arguments);
  }

  // NULL out memory
  subFunc->arguments = NULL;
  subFunc->subfuncLoc = subFunc->numArguments = 0;

  return;
}

void increment_subfunc_parseArray(parseArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: add a subfuncData element to Array                     *
\***************************************************************/
{
  int currFunc = Array->numSubfuncCalls;
  // increment number of subfunction calls
  Array->numSubfuncCalls++;
  // reallocate memory
  Array->subfuncCalls = (definedSubfuncData *)brealloc(Array->subfuncCalls, Array->numSubfuncCalls * sizeof(definedSubfuncData));
  // setup new subfunction
  Array->subfuncCalls[currFunc].subfuncLoc = 0;
  Array->subfuncCalls[currFunc].numArguments = 0;
  Array->subfuncCalls[currFunc].arguments = NULL;

  return;
}

void increment_definedSubfuncStack(definedSubfuncStack *sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: add a subfuncData element to sfData                    *
\***************************************************************/
{ 
  int currFunc = sfData->numActiveSubfuncCalls;
  // increment number of subfunction calls
  sfData->numActiveSubfuncCalls++;
  // reallocate memory
  sfData->subfuncCalls = (definedSubfuncData *)brealloc(sfData->subfuncCalls, sfData->numActiveSubfuncCalls * sizeof(definedSubfuncData));
  // setup new subfunction
  sfData->subfuncCalls[currFunc].subfuncLoc = 0;
  sfData->subfuncCalls[currFunc].numArguments = 0;
  sfData->subfuncCalls[currFunc].arguments = NULL;
  
  return;
}

void remove_definedSubfuncDataStack(definedSubfuncStack *sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: delete a subfuncData element from sfData               *
\***************************************************************/
{ 
  int currFunc = sfData->numActiveSubfuncCalls - 1;

  if (currFunc >= 0)
  { // clear memory
    clear_definedSubfuncData(&sfData->subfuncCalls[currFunc]);
    // decrement number of subfunction calls
    sfData->numActiveSubfuncCalls--;
    // reallocate memory
    sfData->subfuncCalls = (definedSubfuncData *)brealloc(sfData->subfuncCalls, sfData->numActiveSubfuncCalls * sizeof(definedSubfuncData));
  }
  
  return;
}

void copy_argumentData(argumentData *Out, argumentData *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  Out->argMemLoc = In->argMemLoc;
  Out->argDerivExists = In->argDerivExists;
  Out->argDerivLoc = In->argDerivLoc;

  return;
}

void copy_definedSubfuncData(definedSubfuncData *Out, definedSubfuncData *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  int i;

  Out->subfuncLoc = In->subfuncLoc;
  Out->numArguments = In->numArguments;
  Out->arguments = (argumentData *)bmalloc(Out->numArguments * sizeof(argumentData));
  for (i = 0; i < Out->numArguments; i++)
    copy_argumentData(&Out->arguments[i], &In->arguments[i]);

  return;
}

void add_arg_definedSubfuncData(definedSubfuncData *sf, int argMemLoc)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: add an argument to sf                                  *
\***************************************************************/
{
  int currArg = sf->numArguments;
  // increment number of arguments
  sf->numArguments++;
  // reallocate memory
  sf->arguments = (argumentData *)brealloc(sf->arguments, sf->numArguments * sizeof(argumentData));
  // setup new argument
  sf->arguments[currArg].argMemLoc = argMemLoc;
  sf->arguments[currArg].argDerivExists = sf->arguments[currArg].argDerivLoc = 0;

  return;
}

void add_op_expArrayOps(expArrayOps *exp, int memLoc, char op, int in0, int in1)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: add an operation to exp                                *
\***************************************************************/
{
  int currOp = exp->numOps;
  // increment number of operations
  exp->numOps++;
  // reallocate memory
  exp->ops = (expOps *)brealloc(exp->ops, exp->numOps * sizeof(expOps));
  // setup new operation
  exp->ops[currOp].memLoc = memLoc;
  exp->ops[currOp].op = op;
  exp->ops[currOp].in[0] = in0;
  exp->ops[currOp].in[1] = in1;

  return;
}

int lookup_number_type(int *loc, preProcessArrayType *Array, char *name)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES: 1 - found, 0 - not found                       *
* NOTES: lookup a number in ppType based on pCurrNumber         *
\***************************************************************/
{
  int rV = 0, len = strlen(name);

  *loc = -1;

  if (len == Array->nameSize[pCurrNumber] && !strcmp(name, Array->name[pCurrNumber]))
  { // found a match!
    rV = 1;
    *loc = pCurrNumber;
    pCurrNumber++;
  }

  return rV;
}

int lookup_memLoc(int type, int loc, memoryLocations *memLoc, variablegroupArray *varGp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: compute the memory location                            *
\***************************************************************/
{
  int mem = 0;

  if (type == DEFINEDSUBFUNCTIONTYPE)
  { // no memory location setup for this type!
    printf("ERROR: There are no memory locations for defined subfunctions!\n");
    bexit(ERROR_INPUT_SYNTAX);
  }
  else if (type == FUNCTIONTYPE)
  { // lookup memory location
    mem = memLoc->funcStart + loc;
  }
  else if (type == VARIABLETYPE)
  { // lookup memory location
    mem = memLoc->varStart + loc;
  }
  else if (type == VARIABLEGROUPTYPE)
  { // lookup memory location
    mem = memLoc->varStart + varGp->varLoc[loc];
  }
  else if (type == HOMVARIABLEGROUPTYPE)
  { // lookup memory location
    mem = memLoc->varStart + varGp->homLoc[loc];
  }
  else if (type == PARAMETERTYPE)
  { // lookup memory location
    mem = memLoc->paramStart + loc;
  }
  else if (type == PATHVARIABLETYPE)
  { // lookup memory location
    mem = memLoc->pathvarStart + loc;
  }
  else if (type == CONSTANTTYPE)
  { // lookup memory location
    mem = memLoc->constStart + loc;
  }
  else if (type == INLINESUBFUNCTIONTYPE)
  { // lookup memory location
    mem = memLoc->subfuncStart + loc;
  }
  else if (type == NUMBERTYPE)
  { // lookup memory location
    mem = memLoc->numStart + loc;
  }

  return mem;
}

void initialize_defStatement(defStatement *dState, int type, int loc, memoryLocations *memLoc, variablegroupArray *varGp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initialize dState                                      *
\***************************************************************/
{ // setup data about lval
  dState->lvalType = type;
  dState->lvalLoc = loc;
  dState->lvalMemLoc = lookup_memLoc(type, loc, memLoc, varGp);

  // setup data about rval
  initialize_expArrayOps(&dState->rvalExp);
  dState->rvalExp.finalMemLoc = -2;

  return;
}

void copy_expOps(expOps *Out, expOps *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  Out->memLoc = In->memLoc;
  Out->op = In->op;
  Out->in[0] = In->in[0];
  Out->in[1] = In->in[1];

  return;
}

void copy_expArrayOps(expArrayOps *Out, expArrayOps *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  int i;

  Out->numOps = In->numOps;
  Out->finalMemLoc = In->finalMemLoc;
  Out->ops = (expOps *)bmalloc(Out->numOps * sizeof(expOps));
  for (i = 0; i < Out->numOps; i++)
    copy_expOps(&Out->ops[i], &In->ops[i]);

  return;
}

void copy_defStatement(defStatement *Out, defStatement *In)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: copy In to Out                                         *
\***************************************************************/
{
  Out->lvalType = In->lvalType;
  Out->lvalLoc = In->lvalLoc;
  Out->lvalMemLoc = In->lvalMemLoc;

  copy_expArrayOps(&Out->rvalExp, &In->rvalExp);

  return;
}

void setup_memLoc(memoryLocations *memLoc, int *firstFree, preProcessArray *preProcArray, variablegroupArray *vargpArray, int userHom)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup memLoc & firstFree using preProcArray            *
\***************************************************************/
{
  int currLoc = 0;

  if (userHom)
  { // variable
    memLoc->numVars = preProcArray->types[VARIABLETYPE].numType;
  }
  else
  { // variable_group & hom_variable_group
    memLoc->numVars = vargpArray->totalNumVars;
  }

  memLoc->varStart = currLoc;
  currLoc += memLoc->numVars;

  memLoc->numPathVars = preProcArray->types[PATHVARIABLETYPE].numType;
  memLoc->pathvarStart = currLoc;
  currLoc += memLoc->numPathVars;

  memLoc->numParams = preProcArray->types[PARAMETERTYPE].numType;
  memLoc->paramStart = currLoc;
  currLoc += memLoc->numParams;
  memLoc->paramDerivStart = currLoc;
  currLoc += memLoc->numParams * memLoc->numPathVars;

  memLoc->numFuncs = preProcArray->types[FUNCTIONTYPE].numType;
  memLoc->funcStart = currLoc;
  currLoc += memLoc->numFuncs;
  memLoc->funcDerivVStart = currLoc;
  currLoc += memLoc->numFuncs * memLoc->numVars;
  memLoc->funcDerivPStart = currLoc;
  currLoc += memLoc->numFuncs * memLoc->numParams;

  memLoc->numConsts = preProcArray->types[CONSTANTTYPE].numType;
  memLoc->constStart = currLoc;
  currLoc += memLoc->numConsts;

  memLoc->numNums = preProcArray->types[NUMBERTYPE].numType;
  memLoc->numStart = currLoc;
  currLoc += memLoc->numNums;

  memLoc->numSubfuncs = preProcArray->types[INLINESUBFUNCTIONTYPE].numType;
  memLoc->subfuncStart = currLoc;
  currLoc += memLoc->numSubfuncs;
  memLoc->subfuncDerivVStart = currLoc;
  currLoc += memLoc->numSubfuncs * memLoc->numVars;
  memLoc->subfuncDerivPStart = currLoc;
  currLoc += memLoc->numSubfuncs * memLoc->numParams;

  *firstFree = currLoc;

  return;
}

void undefine_preProcessArray_type(preProcessArrayType *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: undefined this type                                    *
\***************************************************************/
{
  int i;

  for (i = 0; i < Array->numType; i++)
    Array->isDefined[i] = 0;

  return;
}

void initialize_parseArray(parseArray *parArray, preProcessArray *preProcArray, variablegroupArray *vargpArray, int userHom)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initialize parArray using preProcArray                 *
\***************************************************************/
{
  parArray->numDefiningStatements = 0;
  parArray->definingStatements = NULL;
  parArray->numSubfuncCalls = 0;
  parArray->subfuncCalls = NULL;

  // copy preprocess info
  copy_preProcessArray(&parArray->ppArray, preProcArray);

  // mark constants, parameters, inline subfunctions & functions as undefined
  undefine_preProcessArray_type(&parArray->ppArray.types[CONSTANTTYPE]);
  undefine_preProcessArray_type(&parArray->ppArray.types[PARAMETERTYPE]);
  undefine_preProcessArray_type(&parArray->ppArray.types[INLINESUBFUNCTIONTYPE]);
  undefine_preProcessArray_type(&parArray->ppArray.types[FUNCTIONTYPE]);

  // setup memory locations and first free memory location
  setup_memLoc(&parArray->memoryLoc, &parArray->firstFreeMemLoc, &parArray->ppArray, vargpArray, userHom);

  return;
}

void initialize_expArrayOps(expArrayOps *exp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initialize exp                                         *
\***************************************************************/
{ // NULL out memory
  exp->numOps = exp->finalMemLoc = 0;
  exp->ops = NULL;
  
  return;
}

void clear_expArrayOps(expArrayOps *exp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear exp                                              *
\***************************************************************/
{
  if (exp->numOps > 0)
  { // release memory
    free(exp->ops);
  }

  // NULL out memory
  exp->ops = NULL;
  exp->numOps = exp->finalMemLoc = 0;

  return;
}

void clear_defStatement(defStatement *dState)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear dState                                           *
\***************************************************************/
{
  // clear rval
  clear_expArrayOps(&dState->rvalExp);
  // clear lval
  dState->lvalType = dState->lvalLoc = dState->lvalMemLoc = 0;

  return;
}

void clear_parseArray(parseArray *parArray)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear parArray                                         *
\***************************************************************/
{
  int i;

  // clear defining statements
  if (parArray->numDefiningStatements > 0)
  {
    for (i = 0; i < parArray->numDefiningStatements; i++)
      clear_defStatement(&parArray->definingStatements[i]); 
    free(parArray->definingStatements);
  }

  // clear subfunction calls
  if (parArray->numSubfuncCalls > 0)
  {
    for (i = 0; i < parArray->numSubfuncCalls; i++)
      clear_definedSubfuncData(&parArray->subfuncCalls[i]);
    free(parArray->subfuncCalls);
  }

  // clear preprocess array
  clear_preProcessArray(&parArray->ppArray);

  // NULL out memory
  parArray->numDefiningStatements = parArray->numSubfuncCalls = parArray->firstFreeMemLoc = 0;
  parArray->definingStatements = NULL;
  parArray->subfuncCalls = NULL;

  return;
}

void load_subFuncData(parseArray *Array, subFuncData *sfData, FILE *IN)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup the defined subfunction data using IN            *
\***************************************************************/
{
  int i, j, loc, strSize = 0, strMem = 2;
  char *str = (char *)bmalloc(strMem * sizeof(char));

  // read in data
  fscanf(IN, "TotalMem: %d;\n", &sfData->totalMem);

  // variables
  fscanf(IN, "Variables: %d;\n", &sfData->numVars);
  // move past variable names
  for (i = 0; i < sfData->numVars; i++)
    scanRestOfLine(IN);

  // constants
  fscanf(IN, "Constants: %d;\n", &sfData->numConsts);
  // setup IAddr - first constant
  sfData->IAddr = Array->memoryLoc.constStart;
  // move past constant names
  for (i = 0; i < sfData->numConsts; i++)
    scanRestOfLine(IN);

  // numbers
  fscanf(IN, "Numbers: %d;\n", &sfData->numNumbers);
  // allocate memory
  sfData->numAddr = (int *)bmalloc(sfData->numNumbers * sizeof(int));
  // read in the numbers and determine memory location
  for (i = 0; i < sfData->numNumbers; i++)
  { // read in number
    strSize = 0;
    str[strSize] = fgetc(IN);
    while(str[strSize] != '\n')
    { // increment size
      strSize++;
      // verify enough memory
      if (strSize >= strMem)
      {
        strMem *= 2;
        str = (char *)brealloc(str, strMem * sizeof(char));
      }
      // read in next char
      str[strSize] = fgetc(IN);
    }
    // setup last char to '\0'
    str[strSize] = '\0';

    // find location of this number
    if (!lookup_preProcessArray_type(&loc, &Array->ppArray.types[NUMBERTYPE], str))
    { // ERROR!!!
      printf("ERROR: Unknown symbol %s when trying to setup defined subfunctions.\n", str);
      bexit(ERROR_INPUT_SYNTAX);
    }
    else
    { // setup memory location
      sfData->numAddr[i] = Array->memoryLoc.numStart + loc;
    }
  }

  // setup function information
  sfData->derivData = (expArrayOps *)bmalloc(sfData->numVars * sizeof(expArrayOps));
  fscanf(IN, "FunctionMem: %d;\n", &sfData->funcData.finalMemLoc);
  fscanf(IN, "FunctionDerivMem:"); 
  for (i = 0; i < sfData->numVars; i++)
    fscanf(IN, "%d", &sfData->derivData[i].finalMemLoc);

  fscanf(IN, ";\n");
  fscanf(IN, "FunctionOps: %d;\n", &sfData->funcData.numOps);
  sfData->funcData.ops = (expOps *)bmalloc(sfData->funcData.numOps * sizeof(expOps));
  for (i = 0; i < sfData->funcData.numOps; i++)
  { // read in ith operation
    readInOp(&sfData->funcData.ops[i], IN);
  }
  
  // seutp derivative information
  fscanf(IN, "FunctionDerivOps:");
  for (i = 0; i < sfData->numVars; i++)
  { // read in number of operations and allocate memory
    fscanf(IN, "%d", &sfData->derivData[i].numOps);
    sfData->derivData[i].ops = (expOps *)bmalloc(sfData->derivData[i].numOps * sizeof(expOps));
  }
  fscanf(IN, ";\n");
  for (i = 0; i < sfData->numVars; i++)
    for (j = 0; j < sfData->derivData[i].numOps; j++)
    { // read in jth operation for ith derivative
      readInOp(&sfData->derivData[i].ops[j], IN);
    }   

  return;
}

void setup_subFuncData(parseArray *Array, subFuncData **sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup the defined subfunction data                     *
\***************************************************************/
{
  int i, size = 0, numSub = Array->ppArray.types[DEFINEDSUBFUNCTIONTYPE].numType;
  char *name = NULL;
  FILE *IN = NULL;  

  // allocate memory
  *sfData = (subFuncData *)bmalloc(numSub * sizeof(subFuncData));

  // read in each one
  for (i = 0; i < numSub; i++)
  { // open file
    size = 1 + snprintf(NULL, 0, "%s.func", Array->ppArray.types[DEFINEDSUBFUNCTIONTYPE].name[i]);
    name = (char *)brealloc(name, size * sizeof(char));
    sprintf(name, "%s.func", Array->ppArray.types[DEFINEDSUBFUNCTIONTYPE].name[i]);
    IN = fopen(name, "r");
    if (IN == NULL)
    { // error
      printf("ERROR: The file '%s' for the defined subfunction '%s' does not exist!\n", name, Array->ppArray.types[DEFINEDSUBFUNCTIONTYPE].name[i]);
      bexit(ERROR_INPUT_SYNTAX);
    }

    // read in the data
    load_subFuncData(Array, &(*sfData)[i], IN);

    // close IN
    fclose(IN);
  }

  // free memory
  free(name);

  return;
}

void clear_subFuncData(int numType, subFuncData **sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear the defined subfunction data                     *
\***************************************************************/
{
  int i, j;

  for (i = 0; i < numType; i++)
  { // clear data
    for (j = 0; j < (*sfData)[i].numVars; j++)
      clear_expArrayOps(&(*sfData)[i].derivData[j]);
    free((*sfData)[i].derivData);
    clear_expArrayOps(&(*sfData)[i].funcData);
    free((*sfData)[i].numAddr);
  }

  // release memory
  free(*sfData);
  *sfData = NULL;

  return;
}

void verify_subFuncCalls(parseArray *parArray, subFuncData *sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: verify the subfunction calls are okay                  *
\***************************************************************/
{
  int i, loc;

  for (i = 0; i < parArray->numSubfuncCalls; i++)
  { // setup the subfunction location
    loc = parArray->subfuncCalls[i].subfuncLoc;
    // verify number of arguments
    if (parArray->subfuncCalls[i].numArguments != sfData[loc].numVars + sfData[loc].numConsts)
    { // argument list not the same
      printf("ERROR: Subfunction call number %d, involving '%s', has an incorrect number of arguments!\n", i+1, parArray->ppArray.types[DEFINEDSUBFUNCTIONTYPE].name[loc]);
      printf("It was expecting %d argument(s), but received %d argument(s).\n", sfData[loc].numVars + sfData[loc].numConsts, parArray->subfuncCalls[i].numArguments);
      bexit(ERROR_INPUT_SYNTAX);
    }
  }

  return;
}

void initialize_definedSubfuncStack(definedSubfuncStack *sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: initialize sfData                                      *
\***************************************************************/
{
  sfData->numActiveSubfuncCalls = 0;
  sfData->subfuncCalls = NULL;

  return;
}

void clear_definedSubfuncStack(definedSubfuncStack *sfData)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: clear sfData                                           *
\***************************************************************/
{
  int i;

  for (i = 0; i < sfData->numActiveSubfuncCalls; i++)
    clear_definedSubfuncData(&sfData->subfuncCalls[i]);
  free(sfData->subfuncCalls);
  sfData->numActiveSubfuncCalls = 0;
  sfData->subfuncCalls = NULL;

  return;
}

int processSystem(parseArray *parArray, subFuncData **sfData, preProcessArray *preProcArray, variablegroupArray *vargpArray, int userHom, int addAllNums, FILE *fp)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: process the file                                       *
\***************************************************************/
{
  int rV = 0, endFile = 0;
  definedSubfuncStack activeSFData;

  pendOfFile = &endFile;

  // setup pArray
  pArray = parArray;

  // initialize global data for lines 
  pLine = NULL;
  pLineLen = 0;

  // setup pCurrNumber -- skip by '0' & '1' so start at memory location 2
  pCurrNumber = 2;

  // setup pAddAllNums
  pAddAllNums = addAllNums;

  // setup the data inside of parArray from preProcArray
  initialize_parseArray(parArray, preProcArray, vargpArray, userHom);

  // seutp pActiveSFData
  pActiveSFData = &activeSFData;

  // initialize pActiveSFData
  initialize_definedSubfuncStack(pActiveSFData);

  // setup pVarGpArray
  pVarGpArray = vargpArray;

  // setup line number
  plineNum = &pParse_flexlineno;
  *plineNum = 1;

  // process the file
  pParse_flexin = fp;
  do
  { // clear out the line
    pLineLen = 1;
    pLine = (char *)brealloc(pLine, pLineLen * sizeof(char));
    pLine[0] = '\0';

    // process the line
    rV = pParse_bisonparse(); 

    // increment line number
    (*plineNum)++;

  } while (!rV && !endFile);

  // setup defined subfunction data
  setup_subFuncData(parArray, sfData);

  // verify that the subfunctions are called with correct arguments
  verify_subFuncCalls(parArray, *sfData);

  // clear memory
  pParse_flexin = NULL;
  pArray = NULL;
  clear_definedSubfuncStack(pActiveSFData);
  pActiveSFData = NULL;

  free(pLine);
  pLineLen = 0;

  return rV;
}

int pParse_flexwrap()
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when parser reaches EOF                         *
\***************************************************************/
{ // parser is complete
  return 1;
}

int pParse_bisonerror(char *s)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when parser reaches an error-should never occur *
\***************************************************************/
{ // error in parser
  if (!strcmp(s,"invalid character"))
    printf("ERROR: The '%s' is an %s in system statement %d.\n", pParse_flextext, s, pParse_flexlineno);
  else
    printf("ERROR: There was an error (%s) near '%s' in system statement %d.\n", s, pParse_flextext, pParse_flexlineno);
  errorStatement_pParse();

  return 0;
}

int isUnary(char op)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES: 1 - unary operation, 0 - binary operation      *
* NOTES: determine if the opeartion is unary or binary          *
\***************************************************************/
{
  if (op == '=' || op == 'N' || op == 'S' || op == 'C' || op == 'X')
    return 1;
  else
    return 0;
}

void readInOp(expOps *op, FILE *IN)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: read in the next operation from IN                     *
\***************************************************************/
{
  fscanf(IN, "%c %d %d", &op->op, &op->memLoc, &op->in[0]);
  if (!isUnary(op->op))
  { // read in second input
    fscanf(IN, "%d", &op->in[1]);
  }
  else
  { // set to -1
    op->in[1] = -1;
  }
  fscanf(IN, "\n");

  return;
}

void load_subFuncData_numbers(preProcessArray *Array, FILE *IN)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup the numbers for defined subfunction data in IN   *
\***************************************************************/
{
  int i, tempInt, loc, strSize = 0, strMem = 2;
  char *str = (char *)bmalloc(strMem * sizeof(char));

  // read in data
  fscanf(IN, "TotalMem: %d;\n", &tempInt);

  // variables
  fscanf(IN, "Variables: %d;\n", &tempInt);
  // move past variable names
  for (i = 0; i < tempInt; i++)
    scanRestOfLine(IN);

  // constants
  fscanf(IN, "Constants: %d;\n", &tempInt);
  // move past constant names
  for (i = 0; i < tempInt; i++)
    scanRestOfLine(IN);

  // numbers
  fscanf(IN, "Numbers: %d;\n", &tempInt);
  // read in the numbers
  for (i = 0; i < tempInt; i++)
  { // read in the number
    strSize = 0;
    str[strSize] = fgetc(IN);
    while(str[strSize] != '\n')
    { // increment size
      strSize++;
      // verify enough memory
      if (strSize >= strMem)
      {
        strMem *= 2;
        str = (char *)brealloc(str, strMem * sizeof(char));
      }
      // read in next char
      str[strSize] = fgetc(IN);
    }
    // setup last char to '\0'
    str[strSize] = '\0';

    // see if this number is known
    if (!lookup_preProcessArray_type(&loc, &Array->types[NUMBERTYPE], str))
    { // add it to the list as defined
      addEntry_preProcessArray_type(&Array->types[NUMBERTYPE], str, 1, 0);
    }
  }

  // release memory
  free(str);

  return;
}

void setup_subFuncData_numbers(preProcessArray *Array)
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: setup the numbers for defined subfunction data         *
\***************************************************************/
{ 
  int i, size = 0, numSub = Array->types[DEFINEDSUBFUNCTIONTYPE].numType;
  char *name = NULL;
  FILE *IN = NULL;

  // loop over each one
  for (i = 0; i < numSub; i++)
  { // open file
    size = 1 + snprintf(NULL, 0, "%s.func", Array->types[DEFINEDSUBFUNCTIONTYPE].name[i]);
    name = (char *)brealloc(name, size * sizeof(char));
    sprintf(name, "%s.func", Array->types[DEFINEDSUBFUNCTIONTYPE].name[i]);
    IN = fopen(name, "r");
    if (IN == NULL)
    { // error
      printf("ERROR: The file '%s' for the defined subfunction '%s' does not exist!\n", name, Array->types[DEFINEDSUBFUNCTIONTYPE].name[i]);
      bexit(ERROR_INPUT_SYNTAX);
    } 

    // read in the data
    load_subFuncData_numbers(Array, IN);

    // close IN
    fclose(IN);
  }

  // free memory
  free(name);

  return;
}

void errorStatement_pParse()
/***************************************************************\
* USAGE:                                                        *
* ARGUMENTS:                                                    *
* RETURN VALUES:                                                *
* NOTES: called when parser reaches an error-should never occur *
\***************************************************************/
{
  printf("Statement %d up to error: '%s'\n", pParse_flexlineno, pLine);
  bexit(ERROR_INPUT_SYNTAX);

  return;
}


